@@ -1,7 +1,5 @@
 import pytest
 
-import uuid
-
 from typing import List
 
 from tests.globals.constants import NUMBER_OF_DOCUMENTS
@@ -11,6 +9,4 @@ from tests.globals.document import datetime_document
 
 @pytest.fixture(scope="session")
 def datetime_documents() -> List:
-    return [
-        datetime_document(uuid.uuid4().__str__()) for _ in range(NUMBER_OF_DOCUMENTS)
-    ]
+    return [datetime_document() for _ in range(NUMBER_OF_DOCUMENTS)]
