@@ -1,7 +1,5 @@
 import pytest
 
-import uuid
-
 from typing import List
 
 from tests.globals.constants import NUMBER_OF_DOCUMENTS
@@ -11,4 +9,4 @@ from tests.globals.document import vector_document
 
 @pytest.fixture(scope="session")
 def vector_documents() -> List:
-    return [vector_document(uuid.uuid4().__str__()) for _ in range(NUMBER_OF_DOCUMENTS)]
+    return [vector_document() for _ in range(NUMBER_OF_DOCUMENTS)]
